# Procesamento de imagens

Decrição :
    Pacote de processamento de imagem versão beta.
        - Histograma das distribuição de cores de uma imagem.
        - Redimencionar a imagem.
        - Verificar a diferença/similiariedade com outra imagem.
        - Visualizar.
        - Ler e salvar. 
    Objetico: Desenvolvida com fins de aprender como criar um package no curso de python da DIO.

## Instalação:

Use o pacote [pip](https://pip.pypa.io/en/stable/) para instalar o img_processing.

```bash
pip install img_processing
```

## Como usar :

Ex.:
``` python
from img_processing.combination import Encontrando_diferença

img  = Encontrando_diferença(imagem_1,imagem_2)
``` 

## Autor :

Nick: Oibug/Nome:Gubio